CON

    hres  = 320
    vres  = 240

PUB Start(_video_ram, _offset, _line_indicator, _scanline_buffer) | i, p

    blnk := _line_indicator
    video_ram := _video_ram
    tiles_rom := @tiles_def
    offset := _offset
    sbuf := _scanline_buffer

    cognew(@driver, 0)

DAT

                    org     0

driver
                    mov     scnt, #vres-4
                    add     scnt, offset

loop
                    rdlong  a, blnk
                    cmp     a, scnt wz
            if_nz   jmp     #$-2                    ' wait for line fetch start

{
                    rdlong  a, blnk
                    cmp     a, scnt wz
            if_z    jmp     #$-2                    ' wait for line fetch end
}

                    add     scnt, #4                ' next line to render
                    cmpsub  scnt, #vres wz,wc
            if_nc   jmp     #render

                    ' vsync

                    ' render line

render              mov     a, scnt
                    shr     a, #3
                    shl     a, #4
                    mov     video_ptr, a            ' multiply by 40 (320 / 8 pixels)
                    shl     video_ptr, #2
                    add     video_ptr, a
                    add     video_ptr, video_ram

                    mov     loffs, scnt
                    and     loffs, #7
                    add     loffs, tiles_rom

                    mov     ccnt, #0
                    mov     ecnt, #hres/8
                    mov     sbuf_ptr, sbuf

rloop               rdword  tile_ptr, video_ptr     ' read tile number to display

                    mov     palette_ptr0, #tile_palette
                    mov     palette_ptr1, #tile_palette
                    mov     a, tile_ptr
                    shr     a, #8
                    and     a, #$0F
                    add     palette_ptr1, a
                    mov     a, tile_ptr
                    shr     a, #12
                    and     a, #$0F
                    add     palette_ptr0, a

                    and     tile_ptr, #$FF
                    shl     tile_ptr, #3            ' 8 bytes per tile
                    add     tile_ptr, loffs
                    rdbyte  tile, tile_ptr          ' pixels, 1 bit per pixel, from msb


                    test    tile, #%1000_0000 wz
        if_z        movs    mv0, palette_ptr0
        if_nz       movs    mv0, palette_ptr1

                    test    tile, #%0100_0000 wz
        if_z        movs    mv1, palette_ptr0
        if_nz       movs    mv1, palette_ptr1

                    test    tile, #%0010_0000 wz
        if_z        movs    mv2, palette_ptr0
        if_nz       movs    mv2, palette_ptr1

                    test    tile, #%0001_0000 wz
        if_z        movs    mv3, palette_ptr0
        if_nz       movs    mv3, palette_ptr1

                    test    tile, #%0000_1000 wz
        if_z        movs    mv4, palette_ptr0
        if_nz       movs    mv4, palette_ptr1

                    test    tile, #%0000_0100 wz
        if_z        movs    mv5, palette_ptr0
        if_nz       movs    mv5, palette_ptr1

                    test    tile, #%0000_0010 wz
        if_z        movs    mv6, palette_ptr0
        if_nz       movs    mv6, palette_ptr1

                    test    tile, #%0000_0001 wz
        if_z        movs    mv7, palette_ptr0
        if_nz       movs    mv7, palette_ptr1

mv1                 mov     pixels0, 0-0
                    shl     pixels0, #16
mv0                 or      pixels0, 0-0
mv3                 mov     pixels1, 0-0
                    shl     pixels1, #16
mv2                 or      pixels1, 0-0
mv5                 mov     pixels2, 0-0
                    shl     pixels2, #16
mv4                 or      pixels2, 0-0

                    wrlong  pixels0, sbuf_ptr
                    add     sbuf_ptr, #4
mv7                 mov     pixels3, 0-0
                    wrlong  pixels1, sbuf_ptr
                    add     sbuf_ptr, #4
                    shl     pixels3, #16
                    wrlong  pixels2, sbuf_ptr
                    add     sbuf_ptr, #4
mv6                 or      pixels3, 0-0
                    wrlong  pixels3, sbuf_ptr
                    add     sbuf_ptr, #4

                    add     ccnt, #8
                    add     video_ptr, #2
                    djnz    ecnt, #rloop

                    jmp     #loop


' driver parameters

blnk                long    0
video_ram           long    0
tiles_rom           long    0
sprite_ram          long    0
offset              long    0
sbuf                long    0

' initialised data and/or presets

inc_dest            long    1 << 9
mask_04             long    $F_0_0_0_F_0_0_0
mask_15             long    $0_F_0_0_0_F_0_0
mask_26             long    $0_0_F_0_0_0_F_0
mask_37             long    $0_0_0_F_0_0_0_F
datamask            long    $0000_FFFF

pixels0             long    0
pixels1             long    0
pixels2             long    0
pixels3             long    0

tile_palette        long    $0000_0000              ' space for 16-colors palette
                    long    $0000_0014
                    long    $0000_A000
                    long    $0000_A014
                    long    $0000_0500
                    long    $0000_0514
                    long    $0000_A500
                    long    $0000_A514

                    long    $0000_528A
                    long    $0000_001E
                    long    $0000_F000
                    long    $0000_F01E
                    long    $0000_0780
                    long    $0000_079E
                    long    $0000_F780
                    long    $0000_F79E

tile_palette_ptr    long    (tile_palette << 16) | tile_palette
palette_size        long    (16 << 16) | 16

' uninitialised data and/or temporaries

a                   res     1
x                   res     1
y                   res     1
cmd                 res     1                       ' command
cmd_out             res     1
data                res     1                       ' data
data_out            res     1
tile                res     1
ptr                 res     1

acnt                res     1                       ' attribute count
ecnt                res     1                       ' element count
lcnt                res     1                       ' line counter
scnt                res     1                       ' scanlines
ccnt                res     1                       ' column counter
loffs               res     1                       ' line offset

sbuf_ptr            res     1
tile_ptr            res     1
sprite_ptr          res     1
video_ptr           res     1
palette_ptr0        res     1
palette_ptr1        res     1

                    fit     $1F0

DAT

tiles_def           byte    %00000000 ' index=0, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %01111110 ' index=1, size=8x8, palette=0
                    byte    %10000001
                    byte    %10100101
                    byte    %10000001
                    byte    %10111101
                    byte    %10011001
                    byte    %10000001
                    byte    %01111110

                    byte    %01111110 ' index=2, size=8x8, palette=0
                    byte    %11111111
                    byte    %11011011
                    byte    %11111111
                    byte    %11000011
                    byte    %11100111
                    byte    %11111111
                    byte    %01111110

                    byte    %01101100 ' index=3, size=8x8, palette=0
                    byte    %11111110
                    byte    %11111110
                    byte    %11111110
                    byte    %01111100
                    byte    %00111000
                    byte    %00010000
                    byte    %00000000

                    byte    %00010000 ' index=4, size=8x8, palette=0
                    byte    %00111000
                    byte    %01111100
                    byte    %11111110
                    byte    %01111100
                    byte    %00111000
                    byte    %00010000
                    byte    %00000000

                    byte    %00111000 ' index=5, size=8x8, palette=0
                    byte    %01111100
                    byte    %00111000
                    byte    %11111110
                    byte    %11111110
                    byte    %01111100
                    byte    %00111000
                    byte    %01111100

                    byte    %00010000 ' index=6, size=8x8, palette=0
                    byte    %00010000
                    byte    %00111000
                    byte    %01111100
                    byte    %11111110
                    byte    %01111100
                    byte    %00111000
                    byte    %01111100

                    byte    %00000000 ' index=7, size=8x8, palette=0
                    byte    %00000000
                    byte    %00011000
                    byte    %00111100
                    byte    %00111100
                    byte    %00011000
                    byte    %00000000
                    byte    %00000000

                    byte    %11111111 ' index=8, size=8x8, palette=0
                    byte    %11111111
                    byte    %11100111
                    byte    %11000011
                    byte    %11000011
                    byte    %11100111
                    byte    %11111111
                    byte    %11111111

                    byte    %00000000 ' index=9, size=8x8, palette=0
                    byte    %00111100
                    byte    %01100110
                    byte    %01000010
                    byte    %01000010
                    byte    %01100110
                    byte    %00111100
                    byte    %00000000

                    byte    %11111111 ' index=10, size=8x8, palette=0
                    byte    %11000011
                    byte    %10011001
                    byte    %10111101
                    byte    %10111101
                    byte    %10011001
                    byte    %11000011
                    byte    %11111111

                    byte    %00001111 ' index=11, size=8x8, palette=0
                    byte    %00000111
                    byte    %00001111
                    byte    %01111101
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000

                    byte    %00111100 ' index=12, size=8x8, palette=0
                    byte    %01100110
                    byte    %01100110
                    byte    %01100110
                    byte    %00111100
                    byte    %00011000
                    byte    %01111110
                    byte    %00011000

                    byte    %00111111 ' index=13, size=8x8, palette=0
                    byte    %00110011
                    byte    %00111111
                    byte    %00110000
                    byte    %00110000
                    byte    %01110000
                    byte    %11110000
                    byte    %11100000

                    byte    %01111111 ' index=14, size=8x8, palette=0
                    byte    %01100011
                    byte    %01111111
                    byte    %01100011
                    byte    %01100011
                    byte    %01100111
                    byte    %11100110
                    byte    %11000000

                    byte    %10011001 ' index=15, size=8x8, palette=0
                    byte    %01011010
                    byte    %00111100
                    byte    %11100111
                    byte    %11100111
                    byte    %00111100
                    byte    %01011010
                    byte    %10011001

                    byte    %10000000 ' index=16, size=8x8, palette=0
                    byte    %11100000
                    byte    %11111000
                    byte    %11111110
                    byte    %11111000
                    byte    %11100000
                    byte    %10000000
                    byte    %00000000

                    byte    %00000010 ' index=17, size=8x8, palette=0
                    byte    %00001110
                    byte    %00111110
                    byte    %11111110
                    byte    %00111110
                    byte    %00001110
                    byte    %00000010
                    byte    %00000000

                    byte    %00011000 ' index=18, size=8x8, palette=0
                    byte    %00111100
                    byte    %01111110
                    byte    %00011000
                    byte    %00011000
                    byte    %01111110
                    byte    %00111100
                    byte    %00011000

                    byte    %01100110 ' index=19, size=8x8, palette=0
                    byte    %01100110
                    byte    %01100110
                    byte    %01100110
                    byte    %01100110
                    byte    %00000000
                    byte    %01100110
                    byte    %00000000

                    byte    %01111111 ' index=20, size=8x8, palette=0
                    byte    %11011011
                    byte    %11011011
                    byte    %01111011
                    byte    %00011011
                    byte    %00011011
                    byte    %00011011
                    byte    %00000000

                    byte    %00111110 ' index=21, size=8x8, palette=0
                    byte    %01100011
                    byte    %00111000
                    byte    %01101100
                    byte    %01101100
                    byte    %00111000
                    byte    %11001100
                    byte    %01111000

                    byte    %00000000 ' index=22, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %01111110
                    byte    %01111110
                    byte    %01111110
                    byte    %00000000

                    byte    %00011000 ' index=23, size=8x8, palette=0
                    byte    %00111100
                    byte    %01111110
                    byte    %00011000
                    byte    %01111110
                    byte    %00111100
                    byte    %00011000
                    byte    %11111111

                    byte    %00011000 ' index=24, size=8x8, palette=0
                    byte    %00111100
                    byte    %01111110
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00000000

                    byte    %00011000 ' index=25, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %01111110
                    byte    %00111100
                    byte    %00011000
                    byte    %00000000

                    byte    %00000000 ' index=26, size=8x8, palette=0
                    byte    %00011000
                    byte    %00001100
                    byte    %11111110
                    byte    %00001100
                    byte    %00011000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=27, size=8x8, palette=0
                    byte    %00110000
                    byte    %01100000
                    byte    %11111110
                    byte    %01100000
                    byte    %00110000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=28, size=8x8, palette=0
                    byte    %00000000
                    byte    %11000000
                    byte    %11000000
                    byte    %11000000
                    byte    %11111110
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=29, size=8x8, palette=0
                    byte    %00100100
                    byte    %01100110
                    byte    %11111111
                    byte    %01100110
                    byte    %00100100
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=30, size=8x8, palette=0
                    byte    %00011000
                    byte    %00111100
                    byte    %01111110
                    byte    %11111111
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=31, size=8x8, palette=0
                    byte    %11111111
                    byte    %11111111
                    byte    %01111110
                    byte    %00111100
                    byte    %00011000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=0, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00110000 ' index=33, size=8x8, palette=0
                    byte    %01111000
                    byte    %01111000
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000
                    byte    %00110000
                    byte    %00000000

                    byte    %01101100 ' index=34, size=8x8, palette=0
                    byte    %01101100
                    byte    %01101100
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %01101100 ' index=35, size=8x8, palette=0
                    byte    %01101100
                    byte    %11111110
                    byte    %01101100
                    byte    %11111110
                    byte    %01101100
                    byte    %01101100
                    byte    %00000000

                    byte    %00110000 ' index=36, size=8x8, palette=0
                    byte    %01111100
                    byte    %11000000
                    byte    %01111000
                    byte    %00001100
                    byte    %11111000
                    byte    %00110000
                    byte    %00000000

                    byte    %00000000 ' index=37, size=8x8, palette=0
                    byte    %11000110
                    byte    %11001100
                    byte    %00011000
                    byte    %00110000
                    byte    %01100110
                    byte    %11000110
                    byte    %00000000

                    byte    %00111000 ' index=38, size=8x8, palette=0
                    byte    %01101100
                    byte    %00111000
                    byte    %01110110
                    byte    %11011100
                    byte    %11001100
                    byte    %01110110
                    byte    %00000000

                    byte    %01100000 ' index=39, size=8x8, palette=0
                    byte    %01100000
                    byte    %11000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00011000 ' index=40, size=8x8, palette=0
                    byte    %00110000
                    byte    %01100000
                    byte    %01100000
                    byte    %01100000
                    byte    %00110000
                    byte    %00011000
                    byte    %00000000

                    byte    %01100000 ' index=41, size=8x8, palette=0
                    byte    %00110000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00110000
                    byte    %01100000
                    byte    %00000000

                    byte    %00000000 ' index=42, size=8x8, palette=0
                    byte    %01100110
                    byte    %00111100
                    byte    %11111111
                    byte    %00111100
                    byte    %01100110
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=43, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %11111100
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=44, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00110000
                    byte    %00110000
                    byte    %01100000

                    byte    %00000000 ' index=45, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=46, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000

                    byte    %00000110 ' index=47, size=8x8, palette=0
                    byte    %00001100
                    byte    %00011000
                    byte    %00110000
                    byte    %01100000
                    byte    %11000000
                    byte    %10000000
                    byte    %00000000

                    byte    %01111100 ' index=48, size=8x8, palette=0
                    byte    %11000110
                    byte    %11001110
                    byte    %11011110
                    byte    %11110110
                    byte    %11100110
                    byte    %01111100
                    byte    %00000000

                    byte    %00110000 ' index=49, size=8x8, palette=0
                    byte    %01110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %11111100
                    byte    %00000000

                    byte    %01111000 ' index=50, size=8x8, palette=0
                    byte    %11001100
                    byte    %00001100
                    byte    %00111000
                    byte    %01100000
                    byte    %11001100
                    byte    %11111100
                    byte    %00000000

                    byte    %01111000 ' index=51, size=8x8, palette=0
                    byte    %11001100
                    byte    %00001100
                    byte    %00111000
                    byte    %00001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00011100 ' index=52, size=8x8, palette=0
                    byte    %00111100
                    byte    %01101100
                    byte    %11001100
                    byte    %11111110
                    byte    %00001100
                    byte    %00011110
                    byte    %00000000

                    byte    %11111100 ' index=53, size=8x8, palette=0
                    byte    %11000000
                    byte    %11111000
                    byte    %00001100
                    byte    %00001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00111000 ' index=54, size=8x8, palette=0
                    byte    %01100000
                    byte    %11000000
                    byte    %11111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %11111100 ' index=55, size=8x8, palette=0
                    byte    %11001100
                    byte    %00001100
                    byte    %00011000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000

                    byte    %01111000 ' index=56, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %01111000 ' index=57, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %01111100
                    byte    %00001100
                    byte    %00011000
                    byte    %01110000
                    byte    %00000000

                    byte    %00000000 ' index=58, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000
                    byte    %00000000
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000

                    byte    %00000000 ' index=59, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000
                    byte    %00000000
                    byte    %00110000
                    byte    %00110000
                    byte    %01100000

                    byte    %00011000 ' index=60, size=8x8, palette=0
                    byte    %00110000
                    byte    %01100000
                    byte    %11000000
                    byte    %01100000
                    byte    %00110000
                    byte    %00011000
                    byte    %00000000

                    byte    %00000000 ' index=61, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000
                    byte    %00000000

                    byte    %01100000 ' index=62, size=8x8, palette=0
                    byte    %00110000
                    byte    %00011000
                    byte    %00001100
                    byte    %00011000
                    byte    %00110000
                    byte    %01100000
                    byte    %00000000

                    byte    %01111000 ' index=63, size=8x8, palette=0
                    byte    %11001100
                    byte    %00001100
                    byte    %00011000
                    byte    %00110000
                    byte    %00000000
                    byte    %00110000
                    byte    %00000000

                    byte    %01111100 ' index=64, size=8x8, palette=0
                    byte    %11000110
                    byte    %11011110
                    byte    %11011110
                    byte    %11011110
                    byte    %11000000
                    byte    %01111000
                    byte    %00000000

                    byte    %00110000 ' index=65, size=8x8, palette=0
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %11111100
                    byte    %11001100
                    byte    %11001100
                    byte    %00000000

                    byte    %11111100 ' index=66, size=8x8, palette=0
                    byte    %01100110
                    byte    %01100110
                    byte    %01111100
                    byte    %01100110
                    byte    %01100110
                    byte    %11111100
                    byte    %00000000

                    byte    %00111100 ' index=67, size=8x8, palette=0
                    byte    %01100110
                    byte    %11000000
                    byte    %11000000
                    byte    %11000000
                    byte    %01100110
                    byte    %00111100
                    byte    %00000000

                    byte    %11111000 ' index=68, size=8x8, palette=0
                    byte    %01101100
                    byte    %01100110
                    byte    %01100110
                    byte    %01100110
                    byte    %01101100
                    byte    %11111000
                    byte    %00000000

                    byte    %11111110 ' index=69, size=8x8, palette=0
                    byte    %01100010
                    byte    %01101000
                    byte    %01111000
                    byte    %01101000
                    byte    %01100010
                    byte    %11111110
                    byte    %00000000

                    byte    %11111110 ' index=70, size=8x8, palette=0
                    byte    %01100010
                    byte    %01101000
                    byte    %01111000
                    byte    %01101000
                    byte    %01100000
                    byte    %11110000
                    byte    %00000000

                    byte    %00111100 ' index=71, size=8x8, palette=0
                    byte    %01100110
                    byte    %11000000
                    byte    %11000000
                    byte    %11001110
                    byte    %01100110
                    byte    %00111110
                    byte    %00000000

                    byte    %11001100 ' index=72, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %11111100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %00000000

                    byte    %01111000 ' index=73, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %00011110 ' index=74, size=8x8, palette=0
                    byte    %00001100
                    byte    %00001100
                    byte    %00001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %11100110 ' index=75, size=8x8, palette=0
                    byte    %01100110
                    byte    %01101100
                    byte    %01111000
                    byte    %01101100
                    byte    %01100110
                    byte    %11100110
                    byte    %00000000

                    byte    %11110000 ' index=76, size=8x8, palette=0
                    byte    %01100000
                    byte    %01100000
                    byte    %01100000
                    byte    %01100010
                    byte    %01100110
                    byte    %11111110
                    byte    %00000000

                    byte    %11000110 ' index=77, size=8x8, palette=0
                    byte    %11101110
                    byte    %11111110
                    byte    %11111110
                    byte    %11010110
                    byte    %11000110
                    byte    %11000110
                    byte    %00000000

                    byte    %11000110 ' index=78, size=8x8, palette=0
                    byte    %11100110
                    byte    %11110110
                    byte    %11011110
                    byte    %11001110
                    byte    %11000110
                    byte    %11000110
                    byte    %00000000

                    byte    %00111000 ' index=79, size=8x8, palette=0
                    byte    %01101100
                    byte    %11000110
                    byte    %11000110
                    byte    %11000110
                    byte    %01101100
                    byte    %00111000
                    byte    %00000000

                    byte    %11111100 ' index=80, size=8x8, palette=0
                    byte    %01100110
                    byte    %01100110
                    byte    %01111100
                    byte    %01100000
                    byte    %01100000
                    byte    %11110000
                    byte    %00000000

                    byte    %01111000 ' index=81, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11011100
                    byte    %01111000
                    byte    %00011100
                    byte    %00000000

                    byte    %11111100 ' index=82, size=8x8, palette=0
                    byte    %01100110
                    byte    %01100110
                    byte    %01111100
                    byte    %01101100
                    byte    %01100110
                    byte    %11100110
                    byte    %00000000

                    byte    %01111000 ' index=83, size=8x8, palette=0
                    byte    %11001100
                    byte    %11100000
                    byte    %01110000
                    byte    %00011100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %11111100 ' index=84, size=8x8, palette=0
                    byte    %10110100
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %11001100 ' index=85, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11111100
                    byte    %00000000

                    byte    %11001100 ' index=86, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00110000
                    byte    %00000000

                    byte    %11000110 ' index=87, size=8x8, palette=0
                    byte    %11000110
                    byte    %11000110
                    byte    %11010110
                    byte    %11111110
                    byte    %11101110
                    byte    %11000110
                    byte    %00000000

                    byte    %11000110 ' index=88, size=8x8, palette=0
                    byte    %11000110
                    byte    %01101100
                    byte    %00111000
                    byte    %00111000
                    byte    %01101100
                    byte    %11000110
                    byte    %00000000

                    byte    %11001100 ' index=89, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %11111110 ' index=90, size=8x8, palette=0
                    byte    %11000110
                    byte    %10001100
                    byte    %00011000
                    byte    %00110010
                    byte    %01100110
                    byte    %11111110
                    byte    %00000000

                    byte    %01111000 ' index=91, size=8x8, palette=0
                    byte    %01100000
                    byte    %01100000
                    byte    %01100000
                    byte    %01100000
                    byte    %01100000
                    byte    %01111000
                    byte    %00000000

                    byte    %11000000 ' index=92, size=8x8, palette=0
                    byte    %01100000
                    byte    %00110000
                    byte    %00011000
                    byte    %00001100
                    byte    %00000110
                    byte    %00000010
                    byte    %00000000

                    byte    %01111000 ' index=93, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %01111000
                    byte    %00000000

                    byte    %00010000 ' index=94, size=8x8, palette=0
                    byte    %00111000
                    byte    %01101100
                    byte    %11000110
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=95, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111111

                    byte    %00110000 ' index=96, size=8x8, palette=0
                    byte    %00110000
                    byte    %00011000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=97, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %00001100
                    byte    %01111100
                    byte    %11001100
                    byte    %01110110
                    byte    %00000000

                    byte    %11100000 ' index=98, size=8x8, palette=0
                    byte    %01100000
                    byte    %01100000
                    byte    %01111100
                    byte    %01100110
                    byte    %01100110
                    byte    %11011100
                    byte    %00000000

                    byte    %00000000 ' index=99, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11000000
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00011100 ' index=100, size=8x8, palette=0
                    byte    %00001100
                    byte    %00001100
                    byte    %01111100
                    byte    %11001100
                    byte    %11001100
                    byte    %01110110
                    byte    %00000000

                    byte    %00000000 ' index=101, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11111100
                    byte    %11000000
                    byte    %01111000
                    byte    %00000000

                    byte    %00111000 ' index=102, size=8x8, palette=0
                    byte    %01101100
                    byte    %01100000
                    byte    %11110000
                    byte    %01100000
                    byte    %01100000
                    byte    %11110000
                    byte    %00000000

                    byte    %00000000 ' index=103, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110110
                    byte    %11001100
                    byte    %11001100
                    byte    %01111100
                    byte    %00001100
                    byte    %11111000

                    byte    %11100000 ' index=104, size=8x8, palette=0
                    byte    %01100000
                    byte    %01101100
                    byte    %01110110
                    byte    %01100110
                    byte    %01100110
                    byte    %11100110
                    byte    %00000000

                    byte    %00110000 ' index=105, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %00001100 ' index=106, size=8x8, palette=0
                    byte    %00000000
                    byte    %00001100
                    byte    %00001100
                    byte    %00001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000

                    byte    %11100000 ' index=107, size=8x8, palette=0
                    byte    %01100000
                    byte    %01100110
                    byte    %01101100
                    byte    %01111000
                    byte    %01101100
                    byte    %11100110
                    byte    %00000000

                    byte    %01110000 ' index=108, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=109, size=8x8, palette=0
                    byte    %00000000
                    byte    %11001100
                    byte    %11111110
                    byte    %11111110
                    byte    %11010110
                    byte    %11000110
                    byte    %00000000

                    byte    %00000000 ' index=110, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %00000000

                    byte    %00000000 ' index=111, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=112, size=8x8, palette=0
                    byte    %00000000
                    byte    %11011100
                    byte    %01100110
                    byte    %01100110
                    byte    %01111100
                    byte    %01100000
                    byte    %11110000

                    byte    %00000000 ' index=113, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110110
                    byte    %11001100
                    byte    %11001100
                    byte    %01111100
                    byte    %00001100
                    byte    %00011110

                    byte    %00000000 ' index=114, size=8x8, palette=0
                    byte    %00000000
                    byte    %11011100
                    byte    %01110110
                    byte    %01100110
                    byte    %01100000
                    byte    %11110000
                    byte    %00000000

                    byte    %00000000 ' index=115, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111100
                    byte    %11000000
                    byte    %01111000
                    byte    %00001100
                    byte    %11111000
                    byte    %00000000

                    byte    %00010000 ' index=116, size=8x8, palette=0
                    byte    %00110000
                    byte    %01111100
                    byte    %00110000
                    byte    %00110000
                    byte    %00110100
                    byte    %00011000
                    byte    %00000000

                    byte    %00000000 ' index=117, size=8x8, palette=0
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01110110
                    byte    %00000000

                    byte    %00000000 ' index=118, size=8x8, palette=0
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00110000
                    byte    %00000000

                    byte    %00000000 ' index=119, size=8x8, palette=0
                    byte    %00000000
                    byte    %11000110
                    byte    %11010110
                    byte    %11111110
                    byte    %11111110
                    byte    %01101100
                    byte    %00000000

                    byte    %00000000 ' index=120, size=8x8, palette=0
                    byte    %00000000
                    byte    %11000110
                    byte    %01101100
                    byte    %00111000
                    byte    %01101100
                    byte    %11000110
                    byte    %00000000

                    byte    %00000000 ' index=121, size=8x8, palette=0
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111100
                    byte    %00001100
                    byte    %11111000

                    byte    %00000000 ' index=122, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111100
                    byte    %10011000
                    byte    %00110000
                    byte    %01100100
                    byte    %11111100
                    byte    %00000000

                    byte    %00011100 ' index=123, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %11100000
                    byte    %00110000
                    byte    %00110000
                    byte    %00011100
                    byte    %00000000

                    byte    %00011000 ' index=124, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00000000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00000000

                    byte    %11100000 ' index=125, size=8x8, palette=0
                    byte    %00110000
                    byte    %00110000
                    byte    %00011100
                    byte    %00110000
                    byte    %00110000
                    byte    %11100000
                    byte    %00000000

                    byte    %01110110 ' index=126, size=8x8, palette=0
                    byte    %11011100
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=127, size=8x8, palette=0
                    byte    %00010000
                    byte    %00111000
                    byte    %01101100
                    byte    %11000110
                    byte    %11000110
                    byte    %11111110
                    byte    %00000000

                    byte    %01111000 ' index=128, size=8x8, palette=0
                    byte    %11001100
                    byte    %11000000
                    byte    %11001100
                    byte    %01111000
                    byte    %00011000
                    byte    %00001100
                    byte    %01111000

                    byte    %00000000 ' index=129, size=8x8, palette=0
                    byte    %11001100
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00011100 ' index=130, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11111100
                    byte    %11000000
                    byte    %01111000
                    byte    %00000000

                    byte    %01111110 ' index=131, size=8x8, palette=0
                    byte    %11000011
                    byte    %00111100
                    byte    %00000110
                    byte    %00111110
                    byte    %01100110
                    byte    %00111111
                    byte    %00000000

                    byte    %11001100 ' index=132, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %00001100
                    byte    %01111100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %11100000 ' index=133, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %00001100
                    byte    %01111100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00110000 ' index=134, size=8x8, palette=0
                    byte    %00110000
                    byte    %01111000
                    byte    %00001100
                    byte    %01111100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00000000 ' index=135, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11000000
                    byte    %11000000
                    byte    %01111000
                    byte    %00001100
                    byte    %00111000

                    byte    %01111110 ' index=136, size=8x8, palette=0
                    byte    %11000011
                    byte    %00111100
                    byte    %01100110
                    byte    %01111110
                    byte    %01100000
                    byte    %00111100
                    byte    %00000000

                    byte    %11001100 ' index=137, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11111100
                    byte    %11000000
                    byte    %01111000
                    byte    %00000000

                    byte    %11100000 ' index=138, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11111100
                    byte    %11000000
                    byte    %01111000
                    byte    %00000000

                    byte    %11001100 ' index=139, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %01111100 ' index=140, size=8x8, palette=0
                    byte    %11000110
                    byte    %00111000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00111100
                    byte    %00000000

                    byte    %11100000 ' index=141, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %11000110 ' index=142, size=8x8, palette=0
                    byte    %00111000
                    byte    %01101100
                    byte    %11000110
                    byte    %11111110
                    byte    %11000110
                    byte    %11000110
                    byte    %00000000

                    byte    %00110000 ' index=143, size=8x8, palette=0
                    byte    %00110000
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11111100
                    byte    %11001100
                    byte    %00000000

                    byte    %00011100 ' index=144, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111100
                    byte    %01100000
                    byte    %01111000
                    byte    %01100000
                    byte    %11111100
                    byte    %00000000

                    byte    %00000000 ' index=145, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111111
                    byte    %00001100
                    byte    %01111111
                    byte    %11001100
                    byte    %01111111
                    byte    %00000000

                    byte    %00111110 ' index=146, size=8x8, palette=0
                    byte    %01101100
                    byte    %11001100
                    byte    %11111110
                    byte    %11001100
                    byte    %11001100
                    byte    %11001110
                    byte    %00000000

                    byte    %01111000 ' index=147, size=8x8, palette=0
                    byte    %11001100
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=148, size=8x8, palette=0
                    byte    %11001100
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=149, size=8x8, palette=0
                    byte    %11100000
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %01111000 ' index=150, size=8x8, palette=0
                    byte    %11001100
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00000000 ' index=151, size=8x8, palette=0
                    byte    %11100000
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00000000 ' index=152, size=8x8, palette=0
                    byte    %11001100
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111100
                    byte    %00001100
                    byte    %11111000

                    byte    %11000011 ' index=153, size=8x8, palette=0
                    byte    %00011000
                    byte    %00111100
                    byte    %01100110
                    byte    %01100110
                    byte    %00111100
                    byte    %00011000
                    byte    %00000000

                    byte    %11001100 ' index=154, size=8x8, palette=0
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00011000 ' index=155, size=8x8, palette=0
                    byte    %00011000
                    byte    %01111110
                    byte    %11000000
                    byte    %11000000
                    byte    %01111110
                    byte    %00011000
                    byte    %00011000

                    byte    %00111000 ' index=156, size=8x8, palette=0
                    byte    %01101100
                    byte    %01100100
                    byte    %11110000
                    byte    %01100000
                    byte    %11100110
                    byte    %11111100
                    byte    %00000000

                    byte    %11001100 ' index=157, size=8x8, palette=0
                    byte    %11001100
                    byte    %01111000
                    byte    %11111100
                    byte    %00110000
                    byte    %11111100
                    byte    %00110000
                    byte    %00110000

                    byte    %11111000 ' index=158, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %11111010
                    byte    %11000110
                    byte    %11001111
                    byte    %11000110
                    byte    %11000111

                    byte    %00001110 ' index=159, size=8x8, palette=0
                    byte    %00011011
                    byte    %00011000
                    byte    %00111100
                    byte    %00011000
                    byte    %00011000
                    byte    %11011000
                    byte    %01110000

                    byte    %00011100 ' index=160, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111000
                    byte    %00001100
                    byte    %01111100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00111000 ' index=161, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110000
                    byte    %00110000
                    byte    %00110000
                    byte    %00110000
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=162, size=8x8, palette=0
                    byte    %00011100
                    byte    %00000000
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=163, size=8x8, palette=0
                    byte    %00011100
                    byte    %00000000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111110
                    byte    %00000000

                    byte    %00000000 ' index=164, size=8x8, palette=0
                    byte    %11111000
                    byte    %00000000
                    byte    %11111000
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %00000000

                    byte    %11111100 ' index=165, size=8x8, palette=0
                    byte    %00000000
                    byte    %11001100
                    byte    %11101100
                    byte    %11111100
                    byte    %11011100
                    byte    %11001100
                    byte    %00000000

                    byte    %00111100 ' index=166, size=8x8, palette=0
                    byte    %01101100
                    byte    %01101100
                    byte    %00111110
                    byte    %00000000
                    byte    %01111110
                    byte    %00000000
                    byte    %00000000

                    byte    %00111000 ' index=167, size=8x8, palette=0
                    byte    %01101100
                    byte    %01101100
                    byte    %00111000
                    byte    %00000000
                    byte    %01111100
                    byte    %00000000
                    byte    %00000000

                    byte    %00110000 ' index=168, size=8x8, palette=0
                    byte    %00000000
                    byte    %00110000
                    byte    %01100000
                    byte    %11000000
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=169, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %11111100
                    byte    %11000000
                    byte    %11000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=170, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %11111100
                    byte    %00001100
                    byte    %00001100
                    byte    %00000000
                    byte    %00000000

                    byte    %11000011 ' index=171, size=8x8, palette=0
                    byte    %11000110
                    byte    %11001100
                    byte    %11011110
                    byte    %00110011
                    byte    %01100110
                    byte    %11001100
                    byte    %00001111

                    byte    %11000011 ' index=172, size=8x8, palette=0
                    byte    %11000110
                    byte    %11001100
                    byte    %11011011
                    byte    %00110111
                    byte    %01101111
                    byte    %11001111
                    byte    %00000011

                    byte    %00011000 ' index=173, size=8x8, palette=0
                    byte    %00011000
                    byte    %00000000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00000000

                    byte    %00000000 ' index=174, size=8x8, palette=0
                    byte    %00110011
                    byte    %01100110
                    byte    %11001100
                    byte    %01100110
                    byte    %00110011
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=175, size=8x8, palette=0
                    byte    %11001100
                    byte    %01100110
                    byte    %00110011
                    byte    %01100110
                    byte    %11001100
                    byte    %00000000
                    byte    %00000000

                    byte    %00100010 ' index=176, size=8x8, palette=0
                    byte    %10001000
                    byte    %00100010
                    byte    %10001000
                    byte    %00100010
                    byte    %10001000
                    byte    %00100010
                    byte    %10001000

                    byte    %01010101 ' index=177, size=8x8, palette=0
                    byte    %10101010
                    byte    %01010101
                    byte    %10101010
                    byte    %01010101
                    byte    %10101010
                    byte    %01010101
                    byte    %10101010

                    byte    %11011011 ' index=178, size=8x8, palette=0
                    byte    %01110111
                    byte    %11011011
                    byte    %11101110
                    byte    %11011011
                    byte    %01110111
                    byte    %11011011
                    byte    %11101110

                    byte    %00011000 ' index=179, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=180, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %11111000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=181, size=8x8, palette=0
                    byte    %00011000
                    byte    %11111000
                    byte    %00011000
                    byte    %11111000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00110110 ' index=182, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %11110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00000000 ' index=183, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00000000 ' index=184, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111000
                    byte    %00011000
                    byte    %11111000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00110110 ' index=185, size=8x8, palette=0
                    byte    %00110110
                    byte    %11110110
                    byte    %00000110
                    byte    %11110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=186, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00000000 ' index=187, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111110
                    byte    %00000110
                    byte    %11110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=188, size=8x8, palette=0
                    byte    %00110110
                    byte    %11110110
                    byte    %00000110
                    byte    %11111110
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00110110 ' index=189, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %11111110
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00011000 ' index=190, size=8x8, palette=0
                    byte    %00011000
                    byte    %11111000
                    byte    %00011000
                    byte    %11111000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=191, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=192, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00011000 ' index=193, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=194, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=195, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00000000 ' index=196, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00011000 ' index=197, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %11111111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=198, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00110110 ' index=199, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00110111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=200, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110111
                    byte    %00110000
                    byte    %00111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=201, size=8x8, palette=0
                    byte    %00000000
                    byte    %00111111
                    byte    %00110000
                    byte    %00110111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=202, size=8x8, palette=0
                    byte    %00110110
                    byte    %11110111
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=203, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %11110111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=204, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110111
                    byte    %00110000
                    byte    %00110111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00000000 ' index=205, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00110110 ' index=206, size=8x8, palette=0
                    byte    %00110110
                    byte    %11110111
                    byte    %00000000
                    byte    %11110111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00011000 ' index=207, size=8x8, palette=0
                    byte    %00011000
                    byte    %11111111
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00110110 ' index=208, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=209, size=8x8, palette=0
                    byte    %00000000
                    byte    %11111111
                    byte    %00000000
                    byte    %11111111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00000000 ' index=210, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=211, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %00111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00011000 ' index=212, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=213, size=8x8, palette=0
                    byte    %00000000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00000000 ' index=214, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00111111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00110110 ' index=215, size=8x8, palette=0
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110
                    byte    %11111111
                    byte    %00110110
                    byte    %00110110
                    byte    %00110110

                    byte    %00011000 ' index=216, size=8x8, palette=0
                    byte    %00011000
                    byte    %11111111
                    byte    %00011000
                    byte    %11111111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=217, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %11111000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=218, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00011111
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %11111111 ' index=219, size=8x8, palette=0
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111

                    byte    %00000000 ' index=220, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111

                    byte    %11110000 ' index=221, size=8x8, palette=0
                    byte    %11110000
                    byte    %11110000
                    byte    %11110000
                    byte    %11110000
                    byte    %11110000
                    byte    %11110000
                    byte    %11110000

                    byte    %00001111 ' index=222, size=8x8, palette=0
                    byte    %00001111
                    byte    %00001111
                    byte    %00001111
                    byte    %00001111
                    byte    %00001111
                    byte    %00001111
                    byte    %00001111

                    byte    %11111111 ' index=223, size=8x8, palette=0
                    byte    %11111111
                    byte    %11111111
                    byte    %11111111
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=224, size=8x8, palette=0
                    byte    %00000000
                    byte    %01110110
                    byte    %11011100
                    byte    %11001000
                    byte    %11011100
                    byte    %01110110
                    byte    %00000000

                    byte    %00000000 ' index=225, size=8x8, palette=0
                    byte    %01111000
                    byte    %11001100
                    byte    %11111000
                    byte    %11001100
                    byte    %11111000
                    byte    %11000000
                    byte    %11000000

                    byte    %00000000 ' index=226, size=8x8, palette=0
                    byte    %11111100
                    byte    %11001100
                    byte    %11000000
                    byte    %11000000
                    byte    %11000000
                    byte    %11000000
                    byte    %00000000

                    byte    %00000000 ' index=227, size=8x8, palette=0
                    byte    %11111110
                    byte    %01101100
                    byte    %01101100
                    byte    %01101100
                    byte    %01101100
                    byte    %01101100
                    byte    %00000000

                    byte    %11111100 ' index=228, size=8x8, palette=0
                    byte    %11001100
                    byte    %01100000
                    byte    %00110000
                    byte    %01100000
                    byte    %11001100
                    byte    %11111100
                    byte    %00000000

                    byte    %00000000 ' index=229, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111110
                    byte    %11011000
                    byte    %11011000
                    byte    %11011000
                    byte    %01110000
                    byte    %00000000

                    byte    %00000000 ' index=230, size=8x8, palette=0
                    byte    %01100110
                    byte    %01100110
                    byte    %01100110
                    byte    %01100110
                    byte    %01111100
                    byte    %01100000
                    byte    %11000000

                    byte    %00000000 ' index=231, size=8x8, palette=0
                    byte    %01110110
                    byte    %11011100
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00000000

                    byte    %11111100 ' index=232, size=8x8, palette=0
                    byte    %00110000
                    byte    %01111000
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00110000
                    byte    %11111100

                    byte    %00111000 ' index=233, size=8x8, palette=0
                    byte    %01101100
                    byte    %11000110
                    byte    %11111110
                    byte    %11000110
                    byte    %01101100
                    byte    %00111000
                    byte    %00000000

                    byte    %00111000 ' index=234, size=8x8, palette=0
                    byte    %01101100
                    byte    %11000110
                    byte    %11000110
                    byte    %01101100
                    byte    %01101100
                    byte    %11101110
                    byte    %00000000

                    byte    %00011100 ' index=235, size=8x8, palette=0
                    byte    %00110000
                    byte    %00011000
                    byte    %01111100
                    byte    %11001100
                    byte    %11001100
                    byte    %01111000
                    byte    %00000000

                    byte    %00000000 ' index=236, size=8x8, palette=0
                    byte    %00000000
                    byte    %01111110
                    byte    %11011011
                    byte    %11011011
                    byte    %01111110
                    byte    %00000000
                    byte    %00000000

                    byte    %00000110 ' index=237, size=8x8, palette=0
                    byte    %00001100
                    byte    %01111110
                    byte    %11011011
                    byte    %11011011
                    byte    %01111110
                    byte    %01100000
                    byte    %11000000

                    byte    %00111000 ' index=238, size=8x8, palette=0
                    byte    %01100000
                    byte    %11000000
                    byte    %11111000
                    byte    %11000000
                    byte    %01100000
                    byte    %00111000
                    byte    %00000000

                    byte    %01111000 ' index=239, size=8x8, palette=0
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %11001100
                    byte    %00000000

                    byte    %00000000 ' index=240, size=8x8, palette=0
                    byte    %11111100
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000
                    byte    %00000000

                    byte    %00110000 ' index=241, size=8x8, palette=0
                    byte    %00110000
                    byte    %11111100
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000

                    byte    %01100000 ' index=242, size=8x8, palette=0
                    byte    %00110000
                    byte    %00011000
                    byte    %00110000
                    byte    %01100000
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000

                    byte    %00011000 ' index=243, size=8x8, palette=0
                    byte    %00110000
                    byte    %01100000
                    byte    %00110000
                    byte    %00011000
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000

                    byte    %00001110 ' index=244, size=8x8, palette=0
                    byte    %00011011
                    byte    %00011011
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000

                    byte    %00011000 ' index=245, size=8x8, palette=0
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %00011000
                    byte    %11011000
                    byte    %11011000
                    byte    %01110000

                    byte    %00110000 ' index=246, size=8x8, palette=0
                    byte    %00110000
                    byte    %00000000
                    byte    %11111100
                    byte    %00000000
                    byte    %00110000
                    byte    %00110000
                    byte    %00000000

                    byte    %00000000 ' index=247, size=8x8, palette=0
                    byte    %01110110
                    byte    %11011100
                    byte    %00000000
                    byte    %01110110
                    byte    %11011100
                    byte    %00000000
                    byte    %00000000

                    byte    %00111000 ' index=248, size=8x8, palette=0
                    byte    %01101100
                    byte    %01101100
                    byte    %00111000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=249, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00011000
                    byte    %00011000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=250, size=8x8, palette=0
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000
                    byte    %00011000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00001111 ' index=251, size=8x8, palette=0
                    byte    %00001100
                    byte    %00001100
                    byte    %00001100
                    byte    %11101100
                    byte    %01101100
                    byte    %00111100
                    byte    %00011100

                    byte    %01111000 ' index=252, size=8x8, palette=0
                    byte    %01101100
                    byte    %01101100
                    byte    %01101100
                    byte    %01101100
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %01110000 ' index=253, size=8x8, palette=0
                    byte    %00011000
                    byte    %00110000
                    byte    %01100000
                    byte    %01111000
                    byte    %00000000
                    byte    %00000000
                    byte    %00000000

                    byte    %00000000 ' index=254, size=8x8, palette=0
                    byte    %00000000
                    byte    %00111100
                    byte    %00111100
                    byte    %00111100
                    byte    %00111100
                    byte    %00000000
                    byte    %00000000
