CON

    _XINFREQ = 5_000_000
    _CLKMODE = XTAL1 + PLL16X

    COLUMNS = 40
    ROWS    = 30

    BLACK         = 0
    DARK_BLUE     = 1
    DARK_RED      = 2
    DARK_MAGENTA  = 3
    DARK_GREEN    = 4
    DARK_CYAN     = 5
    DARK_YELLOW   = 6
    LIGHT_GREY    = 7
    DARK_GREY     = 8
    BLUE          = 9
    RED           = 10
    MAGENTA       = 11
    GREEN         = 12
    CYAN          = 13
    YELLOW        = 14
    WHITE         = 15

VAR

    long    t_col
    long    t_row
    long    video_ptr
    word    video_ram[40 * 30]
    word    t_attr

    long volume[3]

OBJ

    Video: "lcd_driver"

PUB Start | i, addr, errorString, note, channel, musicPointer

    ' initialization
    wordfill(@video_ram, (1 << 12) | (15 << 8), 40 * 30)
    Video.Start(@video_ram)

    t_col := 0
    t_row := 0
    t_attr := constant((DARK_BLUE << 12) | (WHITE << 8))     
    video_ptr := (t_row * COLUMNS) + t_col
    waitcnt(CNT + CLKFREQ)
    
    strxy(5, 1, string("*** PROPELLER LCD TERMINAL ***", 13, 10))
    
    str(string(13, 10, "READY", 13, 10))

                             
PUB str(stringptr)

'' Print a zero-terminated string

    repeat strsize(stringptr)
        out(byte[stringptr++])

PUB strxy(x, y, stringptr)

'' Print a zero-terminated string

    t_col := x
    t_row := y
    video_ptr := (t_row * COLUMNS) + t_col

    repeat strsize(stringptr)
        out(byte[stringptr++])

PUB dec(value) | i

'' Print a decimal number

    if value < 0
        -value
        out("-")

    i := 1_000_000_000

    repeat 10
        if value => i
            out(value / i + "0")
            value //= i
            result~~
        elseif result or i == 1
            out("0")
        i /= 10

PRI out(c)

'' Output a character

    if c == 13
        t_col := 0
        video_ptr := (t_row * COLUMNS) + t_col
    elseif c == 10
        t_row++
        if t_row => ROWS
            wordmove(@video_ram, @video_ram + COLUMNS, (ROWS - 1) * COLUMNS)
            wordfill(@video_ram + (29 * 40 * 2), t_attr | $20, COLUMNS) 
            t_row--
        video_ptr := (t_row * COLUMNS) + t_col
    elseif c == 12
        t_col := 0
        t_row := 0
        video_ptr := (t_row * COLUMNS) + t_col
    elseif c == 9
        repeat
            out(" ")
        while t_col & 7
    else
        video_ram[video_ptr++] := t_attr | c
        t_col++
        if t_col => COLUMNS
            t_col := 0
            t_row++
            if t_row => ROWS
                wordmove(@video_ram, @video_ram + COLUMNS, (ROWS - 1) * COLUMNS)
                wordfill(@video_ram + (29 * 40 * 2), t_attr | $20, COLUMNS) 
                t_row--
                video_ptr := (t_row * COLUMNS) + t_col

PUB hex(value, digits)

'' Print a hexadecimal number

    value <<= (8 - digits) << 2
    repeat digits
        out(lookupz((value <-= 4) & $F : "0".."9", "A".."F"))
        
